/*
Copyright (c) 2012, Petr Pehal, Jakub Šplíchal, Rostislav Stríž,

All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer
    in the documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
/*************************************************************************************************
**
** file:    DetailListDelegate.qml
** date:    10.12.2011
** authors: Petr Pehal,      xpehal00@stud.fit.vutbr.cz
**          Rostislav Striz, xstriz03@stud.fit.vutbr.cz
**          Jakub Splichal,  xsplic03@stud.fit.vutbr.cz
**
**************************************************************************************************/

import Qt 4.7
import QtQuick 1.1
import Qt.labs.components.native 1.0

// DELEGATE FOR MAIN SCREEN - LIST OF PROFILES

Component {

    BorderImage {
        width: listView.width
        height: 70

        border.bottom: 10
        border.top: 10
        border.left: 10
        border.right: 30

        source: listViewMouseArea.pressed ? "qrc:/icons/listitem_pressed.png" :
                                            model.modelData.conditionsMet && model.modelData.active ? "qrc:/icons/listitem_highlight.png" :
                                                                                                      "qrc:/icons/listitem.png"

        property bool delClicked

        // activity checkbox
        CheckBox{
            z: 2

            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.verticalCenter: parent.verticalCenter

            checked: model.modelData.active

            // set active/nonactive onclick
            onClicked: {
                model.modelData.active = !model.modelData.active
            }
        }


        // profile name
        Text {
            anchors.left: parent.left
            anchors.leftMargin: 100
            anchors.verticalCenter: parent.verticalCenter

            font.pixelSize: Math.round(parent.height/2)

            style: Text.Raised

            text: name
        }


        // delete button
        Image {
            z: 1

            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: 50

            source: "qrc:/icons/close.png"

            // clickable
            MouseArea {
                anchors.fill: parent

                onHoveredChanged: {
                    delClicked = !delClicked
                    if(delClicked)
                        parent.source = "qrc:/icons/close_pressed.png"
                    else
                        parent.source = "qrc:/icons/close.png"
                }

                // open confirmation dialog to delete
                onClicked: {
                    listView.selectedToDelete = index
                    qd.open()
                }
            }

        }

        ProfileDialog {
            id: profileDialog
            windowTitle: qsTr("Rename Profile")
            acceptButtonText: qsTr("Rename")

            onAccepted: {
                Profiler.renameProfile(index, profileName())
            }
        }


        // PROFILE SELECTION
        MouseArea {
            id: listViewMouseArea

            anchors.fill: parent

            onPressAndHold: {
                profileDialog.setProfileName(model.modelData.name)
                profileDialog.show()
            }

            onClicked: {
                Profiler.selectProfile(index)
                // Switch to details view
                headerView.applicationName = "Profile: " + name
                listView.currentIndex = index
                detailViewPic.source = model.modelData.active ? "qrc:/icons/greenStone.png" : "qrc:/icons/redStone.png"
                detailViewStatus.text = model.modelData.active ? "profile active" : "profile not active"
                detailListView.switchState()
            }
        }


    }
}
